Crate diesel_selectable_macro

Crate diesel_selectable_macro 

A Selectable derive trait for deriving a select method on a struct that performs a Diesel query by key names, rather than position (as [diesel::Queryable] does).

Derive Macros

Selectable
Provide a .select() function based on the struct’s fields.